==> zio-aws-textract_2.13-5.17.295.12-sources.jar: zio/aws/textract/model/RelationshipType.scala <==
package zio.aws.textract.model
import scala.jdk.CollectionConverters._
sealed trait RelationshipType {
  def unwrap: software.amazon.awssdk.services.textract.model.RelationshipType
}
object RelationshipType {
  def wrap(
      value: software.amazon.awssdk.services.textract.model.RelationshipType
  ): zio.aws.textract.model.RelationshipType = value match {
    case software.amazon.awssdk.services.textract.model.RelationshipType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.VALUE =>
      val r = VALUE
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.CHILD =>
      val r = CHILD
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.COMPLEX_FEATURES =>
      val r = COMPLEX_FEATURES
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.MERGED_CELL =>
      val r = MERGED_CELL
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.TITLE =>
      val r = TITLE
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.ANSWER =>
      val r = ANSWER
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.UNKNOWN_TO_SDK_VERSION
  }
  case object VALUE extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.VALUE
  }
  case object CHILD extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.CHILD
  }
  case object COMPLEX_FEATURES extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.COMPLEX_FEATURES
  }
  case object MERGED_CELL extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.MERGED_CELL
  }
  case object TITLE extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.TITLE
  }
  case object ANSWER extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.ANSWER
  }
}

==> zio-aws-textract_2.13-6.20.69.2-sources.jar: zio/aws/textract/model/RelationshipType.scala <==
package zio.aws.textract.model
import scala.jdk.CollectionConverters._
sealed trait RelationshipType {
  def unwrap: software.amazon.awssdk.services.textract.model.RelationshipType
}
object RelationshipType {
  def wrap(
      value: software.amazon.awssdk.services.textract.model.RelationshipType
  ): zio.aws.textract.model.RelationshipType = value match {
    case software.amazon.awssdk.services.textract.model.RelationshipType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.VALUE =>
      val r = VALUE
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.CHILD =>
      val r = CHILD
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.COMPLEX_FEATURES =>
      val r = COMPLEX_FEATURES
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.MERGED_CELL =>
      val r = MERGED_CELL
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.TITLE =>
      val r = TITLE
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.ANSWER =>
      val r = ANSWER
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.TABLE =>
      val r = TABLE
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.TABLE_TITLE =>
      val r = TABLE_TITLE
      r
    case software.amazon.awssdk.services.textract.model.RelationshipType.TABLE_FOOTER =>
      val r = TABLE_FOOTER
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.UNKNOWN_TO_SDK_VERSION
  }
  case object VALUE extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.VALUE
  }
  case object CHILD extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.CHILD
  }
  case object COMPLEX_FEATURES extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.COMPLEX_FEATURES
  }
  case object MERGED_CELL extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.MERGED_CELL
  }
  case object TITLE extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.TITLE
  }
  case object ANSWER extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.ANSWER
  }
  case object TABLE extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.TABLE
  }
  case object TABLE_TITLE extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.TABLE_TITLE
  }
  case object TABLE_FOOTER extends zio.aws.textract.model.RelationshipType {
    override def unwrap
        : software.amazon.awssdk.services.textract.model.RelationshipType =
      software.amazon.awssdk.services.textract.model.RelationshipType.TABLE_FOOTER
  }
}
